Package: rvest
Version: 0.3.2
Title: Easily Harvest (Scrape) Web Pages
Description: Wrappers around the 'xml2' and 'httr' packages to make it easy to
    download, then manipulate, HTML and XML.
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@rstudio.com", c("aut", "cre")),
    person("RStudio", role = "cph")
    )
Depends: R (>= 3.0.1), xml2
Imports: httr (>= 0.5), selectr, magrittr
Suggests: testthat, knitr, png, stringi (>= 0.3.1), rmarkdown, covr
Encoding: UTF-8
License: GPL-3
LazyData: true
VignetteBuilder: knitr
RoxygenNote: 5.0.1
URL: https://github.com/hadley/rvest
BugReports: https://github.com/hadley/rvest/issues
NeedsCompilation: no
Packaged: 2016-06-16 16:20:43 UTC; hadley
Author: Hadley Wickham [aut, cre],
  RStudio [cph]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Repository: CRAN
Date/Publication: 2016-06-17 08:57:12
Built: R 3.3.2; ; 2017-05-01 22:10:43 UTC; windows
