Package: rvest
Title: Easily Harvest (Scrape) Web Pages
Version: 1.0.4
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@posit.co", role = c("aut", "cre")),
    person("Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Wrappers around the 'xml2' and 'httr' packages to make it
    easy to download, then manipulate, HTML and XML.
License: MIT + file LICENSE
URL: https://rvest.tidyverse.org/, https://github.com/tidyverse/rvest
BugReports: https://github.com/tidyverse/rvest/issues
Depends: R (>= 3.6)
Imports: cli, glue, httr (>= 0.5), lifecycle (>= 1.0.3), magrittr,
        rlang (>= 1.1.0), selectr, tibble, xml2 (>= 1.3)
Suggests: chromote, covr, knitr, R6, readr, repurrrsive, rmarkdown,
        spelling, stringi (>= 0.3.1), testthat (>= 3.0.2), webfakes
VignetteBuilder: knitr
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-02-12 17:13:26 UTC; hadleywickham
Author: Hadley Wickham [aut, cre],
  Posit Software, PBC [cph, fnd]
Maintainer: Hadley Wickham <hadley@posit.co>
Repository: CRAN
Date/Publication: 2024-02-12 20:10:02 UTC
Built: R 4.4.2; ; 2025-10-29 19:19:25 UTC; unix
