# Generated by roxygen2: do not edit by hand

S3method(cookies,session)
S3method(format,button)
S3method(format,input)
S3method(format,select)
S3method(format,textarea)
S3method(headers,session)
S3method(html_form,session)
S3method(html_form,xml_document)
S3method(html_form,xml_node)
S3method(html_form,xml_nodeset)
S3method(html_node,default)
S3method(html_node,session)
S3method(html_nodes,default)
S3method(html_nodes,session)
S3method(html_table,session)
S3method(html_table,xml_document)
S3method(html_table,xml_node)
S3method(html_table,xml_nodeset)
S3method(print,fields)
S3method(print,form)
S3method(print,history)
S3method(print,session)
S3method(read_xml,response)
S3method(read_xml,session)
S3method(status_code,session)
export("%>%")
export(back)
export(follow_link)
export(google_form)
export(guess_encoding)
export(html)
export(html_attr)
export(html_attrs)
export(html_children)
export(html_form)
export(html_name)
export(html_node)
export(html_nodes)
export(html_session)
export(html_table)
export(html_tag)
export(html_text)
export(is.session)
export(jump_to)
export(minimal_html)
export(pluck)
export(repair_encoding)
export(session_history)
export(set_values)
export(submit_form)
export(xml)
export(xml_node)
export(xml_nodes)
export(xml_tag)
importFrom(httr,cookies)
importFrom(httr,headers)
importFrom(httr,status_code)
importFrom(magrittr,"%>%")
importFrom(xml2,read_xml)
